Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Redirection ¶
Redirection is a shell redirection operator seen outside quotes.
type Segment ¶
type Segment struct {
Text string
Normalized string
Separator string
Argv []string
Redirections []Redirection
UnsafeExpansion bool
}
Segment is one shell command segment split on control operators.
Click to show internal directories.
Click to hide internal directories.